/****************************************************************************
Date: 11/11/00
File: ft847fm.cpp
Description:
	Yaseu FT-847 "FM repeater" mode radio driver

	This driver has the "regular" ft847 driver as
	a base class and just overrides a few functions.
	1. Set Tx freq is done by setting repeater offset
	2. Must check PTT before and after reading Rx
	   VFO (from the radio dial) because radio returns
	   Tx freq if transmitting.

History:
*****************************************************************************/
#include "ft847fm.hpp"


FT847FM::FT847FM(const RADIOPARAMS& Params) :
	FT847(Params),
	lRxVFOSave(0),
	lTxOffset(0) {
}

VOID	FT847FM::Update() {
// Test, do nothing. This will prevent reading main VFO

}

/****************************************************************************
Function: SetTxFreq()
Description:
	Set transmit frequency if different from current frequency
Parameters:
	Frequency
Returns:
*****************************************************************************/
VOID	FT847FM::SetTxFreq(DOUBLE dFrequency) {

	// Convert freq to steps
	LONG lTxSteps = FT847::FreqtoSteps(dFrequency);

	// Calculate repeater offset
	LONG lNewTxOffset = lTxSteps - FT847::lRxVFOSteps;

	// different from current value ?
	if (lNewTxOffset >= 0) {
		FT847::OutputBuffer.aParams[0] = FT847_PLUSSHIFT;
	}
	else {
		FT847::OutputBuffer.aParams[0] = FT847_MINUSSHIFT;
		lNewTxOffset = -lNewTxOffset;
	}

	//if ( lNewTxOffset != lTxOffset ) {
		FT847::SendMessage(FT847_REPEATERSHIFT);

		// Save new offset and send to radio
		lTxOffset = lNewTxOffset;
		FT847::SetFrequency(lNewTxOffset, FT847_REPEATEROFFSET);
	//}
	return;
}

VOID	FT847FM::RefreshRxParams() {
// Test, do nothing. This will prevent reading main VFO

}
// end ft847fm.cpp
