/****************************************************************************
Date: 11/11/00
File: ft847fm.hpp
Description:
	Yaseu FT-847 "FM repeater" mode radio driver

	This driver has the "regular" ft847 driver as
	a base class and just overrides a few functions.
	1. Set Tx freq is done by setting repeater offset
	2. Must check PTT before and after reading Rx
	   VFO (from the radio dial) because radio returns
	   Tx freq if transmitting.

History:
*****************************************************************************/
#ifndef FT847FM_HPP
#define FT847FM_HPP

#include "ft847.hpp"	// base class

class FT847FM : public FT847 {
private:

	// Rx Params
	// if user keys mic PTT while reading main VFO
	// the radio will return TX frequency not Rx.
	// This is used to recover from this condition
	LONG		lRxVFOSave;	// saved main VFO frequency

	// Tx Params
	LONG		lTxOffset;	// "repeater" offset 
	
	// No copy constructor or assignment allowed
	// Force compile error if attempted
	FT847FM(const FT847FM&);
	FT847FM& operator=(const FT847FM&);

public:
	// General Functions
	FT847FM(const RADIOPARAMS& Params);
	VOID	Update();

	// Tx Functions
	VOID	SetTxFreq(DOUBLE dFrequency);

	// Rx Functions
	VOID	RefreshRxParams();
};
#endif // end ft847fm.hpp
