 /****************************************************************************
Date: 6/5/00
File: icomtest.cpp
Description: ICOM Radio Driver test program

History:
*****************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <dos.h>
#include <iostream.h>

#include "loctypes.h"
#include "dospc.h"
#include "inttimer.hpp"	// INTERVALTIMER class
#include "radio.hpp"


BOOL	eUpdate = BOOL_FALSE;
RADIOSYSTEM* pRadio = NULL;

/******************
//***** DOS Timer interrupt handler ***************************************
// Note: This routine gets called every ~55mSec. This routine runs
// with the interrupts OFF.
const INT CMD_INT_DOSTIMER   = 0x1C;	// DOS Timer interrupt
static INTHANDLER       pfnDosTimer;    // pointer to "real" DOS timer ISR
VOID INTERRUPT DOSTimerISR(VOID) {

	// Update Interval Timers
	INTERVALTIMER::Update();

	if (eUpdate) {
		pRadio->Update();
	}

        // let DOS timer handler run
        _chain_intr(pfnDosTimer);
}
***************/

VOID	Update() {
	sleep(2);
	for (INT i = 0; i < 100; i++) {
		pRadio->Update();
	}
	return;
}
	



static RADIOPARAMS Params = {

	RADIOTYPE_ICOM, // Manufacturer/Model
	BOOL_TRUE,	// Xceive mode TRUE if using both TX and RX

	// I/O Params
	2, 		// COM or LPT Port number
	0, 		// IO port Base Address

	// Serial port Radios only
	0, 		// IRQ Number
	0, 		// Port bit Rate
	0x4c,		// Radio Destination Address (ICOM IC821)

	// Parallel port radios only
	0,		// initial frequency
	0,		// frequency step size

	// Frequency Converters
	0.0,		//dRxConverter;
	0.0		//dTxConverter;
};


main() {
/*****
	// Hook DOS Timer Interrupt
	disable();
        pfnDosTimer = getvect(CMD_INT_DOSTIMER);
	setvect(CMD_INT_DOSTIMER, DOSTimerISR);
	enable();
*****/

	cout << "IC-821 Test program 3" << endl;
	cout << "Runs at 1200 bps on COM 2" << endl;

	cout << endl << "Setting up Driver..." << endl;
	pRadio = RADIOSYSTEM::NewInstance(Params);
	if (!pRadio) {
		cout << "ERROR - Driver failed to initialize" << endl;
		return 1;
	}

	// First wait for radio to be ready
	Update();
	if ( !(pRadio->IsReady()) ) {
		cout << "ERROR1: NOT READY after initialization" << endl;
	}
	cout << "OK, Radio should be in FULL DUPLEX mode." << endl;

	// Next, Get Rx params
	cout << endl << "Polling Receiver frequency..." << endl;
	pRadio->RefreshRxParams();
	Update();	// Set SUB Band
	Update();	// Get Mode
	Update();	// Get Frequency

	if ( !(pRadio->IsReady()) ) {
		cout << "ERROR2: NOT READY after Refresh params" << endl;
		return 1;
	}

	// Next get Rx freq
	DOUBLE dFrequency = pRadio->GetRxFreq();
	ULONG ulFrequency = (ULONG) dFrequency;
	cout << "Receiver frequency = " << ulFrequency << " Hz" << endl;
	MODULATION eMode = pRadio->GetRxMode();
	cout << "Receiver Modulation code = " << (UINT) eMode << endl;

	else {
/******

		// Loop until user quits
		BOOL eLoop = BOOL_TRUE;
		DOUBLE dFrequency = 0.0;
		UINT unParam;
		eUpdate = BOOL_TRUE;
		while(1) {
/***************************
			pRadio->RefreshRxParams();
			cout << "Polling radio..." << endl;
			sleep(2);
			if (pRadio->IsReady()) {
				if (pRadio->HasUserTunedRx()) {
					cout << "User has tuned";
				}
				else {
					cout << "User has not tuned";
				}
				cout << endl;

				cout << "Current Rx frequency=";
				cout << pRadio->GetRxFreq() << endl;
			}
			else {
				cout << "Error, Poll failed" << endl;
			}
***************************/

			cout << "Please enter RX frequency in MHz: ";
			cin >> dFrequency;
			dFrequency *= 1.0e6;
			pRadio->SetRxFreq(dFrequency);

			cout << "Please enter TX frequency in MHz: ";
			cin >> dFrequency;
			dFrequency *= 1.0e6;
			pRadio->SetTxFreq(dFrequency);

			cout << "Please enter RX mode" << endl;
			cout << "(1=LSB, 2=USB, 3=CW, 4=FM): ";
			cin >> unParam;
			pRadio->SetRxMode((MODULATION) unParam);

			cout << "Please enter TX mode" << endl;
			cout << "(1=LSB, 2=USB, 3=CW, 4=FM): ";
			cin >> unParam;
			pRadio->SetTxMode((MODULATION) unParam);

			cout << "Do you want to run again?" << endl;
			cout << "Enter 1 to run again or 0 to quit: ";
			cin >> unParam;
			if (unParam == 0) {
				break;
			}
		}
		cout << "Thanks for running this test!" << endl;
		eUpdate = BOOL_FALSE;
		delete pRadio;
	}

	// un-hook DOS Timer Interrupt
	disable();
	setvect(CMD_INT_DOSTIMER, pfnDosTimer);
	enable();
*****/
	cout << "Thanks for running this test!" << endl;
	return 0;
}
