// rtest.cpp 1/29/97

#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>

#include "loctypes.h"
#include "dospc.h"
#include "radio.hpp"
#include "inttimer.hpp"


// Radio Parameters
static	RADIOPARAMS Params = {
	//RADIOTYPE_KENWOOD, 	// eType.
	RADIOTYPE_FT847, 	// eType.
	BOOL_TRUE,		// eTransceive;
	//***** I/O Params
	1,			// unPort COM or LPT Port number
	0,			// Address; IO port Base Address
	//***** Serial port Radios only
	0,			// unIRQ; IRQ Number
	0,			// unRate; Port bit Rate
	0, 			// unDestination;
	//***** Parallel port radios only
	0,			// ulInitialFreq;
	0,			// ulFreqStep; frequency step size
	//***** Frequency Converters
	0.0,			// dRxConverter;	
	0.0			// dTxConverter;
};

static DOUBLE dTxFreq = 29.0e6;	// Hz

//***** Shared Objects ************************
static	INTHANDLER	pfnDosTimer;
static	RADIO*		pRadio;

//***** DOS Timer interrupt handler ***************************************
// Note: This routine gets called every ~55mSec. This routine runs
// with the interrupts OFF.
VOID INTERRUPT DOSTimerISR(VOID) {

	// Update Interval Timers
	INTERVALTIMER::Update();

        // Run Controller background processing routine
	pRadio->Update();

        // let DOS timer handler run
        _chain_intr(pfnDosTimer);
}

BOOL	Poll(RADIO* pRadio) {

	pRadio->StartInfoPoll();
	const INT BIGNUMBER = 10000;

	for (INT i = 0; i < BIGNUMBER; i++) {
		pRadio->Update();
		if (pRadio->IsReady()) {
			return BOOL_TRUE;
		}
	}
	return BOOL_FALSE;	// timeout
}


//***** main routine *******************
int main(){
	//***** Create Radio
	printf("Creating radio object type %d\n", Params.eType);
	pRadio = new RADIO(Params);
	if (!(pRadio->IsOperational())) {
		printf("Radio not operational\n");
		return 1;
	}

	//***** Start Background Processing
/*****
	disable();
        pfnDosTimer = getvect(0x1c);
	setvect(0x1c, DOSTimerISR);
	enable();
*****/

	//***** Get radio initial conditions *****
	printf("Polling Radio...\n");
	if ( !Poll(pRadio) ) {
		printf("ERROR, InfoPoll timeout\n");
		return 1;
	}

	printf("Current Frequency = %lf\n", pRadio->GetRxFreq());
	printf("Current Mode = %d\n", (INT) pRadio->GetRxMode() );
	printf("Rx Freq Changed Flag= %d\n", (INT) pRadio->IsRxFreqChanged());

	printf("Setting Rx Mode to USB\n"); 
	pRadio->SetRxMode(MODULATION_USB);

	printf("Setting Tx freq to %lf Hz\n", dTxFreq);
	pRadio->SetTxFreq(dTxFreq);

	printf("Setting Tx Mode to LSB\n");
	pRadio->SetTxMode(MODULATION_LSB);

	printf("\n***** Change Frequency Test *****\n");
	printf("Rx Freq Changed Flag= %d\n", (INT) pRadio->IsRxFreqChanged());
	printf("Waiting 4 seconds, user can change frequency manually\n");
	sleep(4);
	if ( !Poll(pRadio) ) {
		printf("ERROR, InfoPoll time out\n");
		return 1;
	}
	printf("Rx Freq Changed Flag= %d\n", (INT) pRadio->IsRxFreqChanged());
	printf("New Rx Frequency = %lf Hz\n", pRadio->GetRxFreq());

	dTxFreq += 1e3;	// add 1KHz
	printf("Setting Tx freq to %lf Hz\n", dTxFreq);
	pRadio->SetTxFreq(dTxFreq);

	sleep(1);

	// Cleanup
	printf("Destroying Radio Object\n");
	delete pRadio;

	printf("All tests complete\n");
	return 0;
}
