/****************************************************************************
Copyright 1997 Anthony Monteiro

Date: 11/19/97
File: xpdrinv.cpp
Description: INVERTING LINEAR TRANSPONDER CLASS

	The output frequency of an inverting linear transponder
	tracks the input frequency "inversely" (what else?):

		InputFreq = TRANSLATION - OutputFreq
		OuputFreq = TRANSLATION  - InputFreq 

 	The output modulation mode is the same as the input mode 
	except for SSB where the sideband is inverted.

History:
	11/19/97 Version 1.0
*****************************************************************************/
#include "xpdrinv.hpp"

// Private 
MODULATION	INVERTINGTRANSPONDER::InvertSideband(MODULATION eMode) {

		MODULATION eReturnMode;

		switch(eMode) {
		case MODULATION_USB:
			eReturnMode = MODULATION_LSB;
			break;
		case MODULATION_LSB:
			eReturnMode = MODULATION_USB;
			break;
		default: // no change for any other modes
			eReturnMode = eMode;
			break;
		}
		return eReturnMode;
}

// constructor
INVERTINGTRANSPONDER::INVERTINGTRANSPONDER(const TRANSPONDERPARAMS& Params) :
	dTranslation(Params.dParam) {

	SetOutputFreq(Params.dOutFreq);
	SetOutputMode(Params.eOutMode);
}

VOID	INVERTINGTRANSPONDER::SetInputFreq(DOUBLE dFreq) {
	TRANSPONDER::dInputFreq = dFreq;
	TRANSPONDER::dOutputFreq = dTranslation - dFreq;
}

VOID	INVERTINGTRANSPONDER::SetOutputFreq(DOUBLE dFreq) {
	TRANSPONDER::dOutputFreq = dFreq;
	TRANSPONDER::dInputFreq = dTranslation - dFreq;
}

VOID	INVERTINGTRANSPONDER::SetInputMode(MODULATION eMode) {
	TRANSPONDER::eInputMode = eMode;
	TRANSPONDER::eOutputMode = InvertSideband(eMode);
}

VOID	INVERTINGTRANSPONDER::SetOutputMode(MODULATION eMode) {
	TRANSPONDER::eOutputMode = eMode;
	TRANSPONDER::eInputMode = InvertSideband(eMode);
}

// end xpdrinv.cpp
